"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.drawNavigationPath = exports.createFragment = exports.clearWayfindingPath = exports.centerMapOnPoint = exports.centerMap = void 0;
exports.getRandomInt = getRandomInt;
exports.wayfindToWaypoint = exports.wayfindBetweenWaypoints = exports.styleUnitsForDestination = exports.styleShape = exports.setUserPosition = exports.setMapVenue = exports.setMapOptions = exports.setFollowBlueDot = void 0;
var _reactNative = require("react-native");
let MapViewManagerCommands = {
  create: 1,
  center: 2,
  setMapVenue: 3,
  centerMapOnPoint: 4,
  setFollowBlueDot: 5,
  setUserPosition: 6,
  setUserPositionXY: 7,
  clearWayfindingPath: 8,
  wayfindToWaypoint: 9,
  wayfindBetweenWaypoints: 10,
  drawNavigationPath: 11,
  styleUnitsForDestination: 12,
  styleShape: 13,
  setMapOptions: 14
  //   styleGeofences: 15,
};

if (_reactNative.Platform.OS == 'ios') {
  MapViewManagerCommands = {
    create: 'create',
    center: 'center',
    setMapVenue: 'setMapVenue',
    centerMapOnPoint: 'centerMapOnPoint',
    setFollowBlueDot: 'setFollowBlueDot',
    setUserPosition: 'setUserPosition',
    setUserPositionXY: 'setUserPositionXY',
    clearWayfindingPath: 'clearWayfindingPath',
    wayfindToWaypoint: 'wayfindToWaypoint',
    wayfindBetweenWaypoints: 'wayfindBetweenWaypoints',
    drawNavigationPath: 'drawNavigationPath',
    styleUnitsForDestination: 'styleUnitsForDestination',
    styleShape: 'styleShape',
    setMapOptions: 'setMapOptions'
    // styleGeofences: 'styleGeofences',
  };
}

const createFragment = viewId => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.create.toString(), [viewId]);
exports.createFragment = createFragment;
const centerMap = (viewId, rotation, zoom, animationDuration) => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.center.toString(), [rotation, zoom, animationDuration]);
exports.centerMap = centerMap;
function getRandomInt(max) {
  return Math.floor(Math.random() * max);
}
const setMapVenue = _ref => {
  var _mapOptions$user;
  let {
    viewId,
    credentials,
    mapOptions = {}
  } = _ref;
  console.log('Setting Map Options');
  if (mapOptions && mapOptions.user && (_mapOptions$user = mapOptions.user) !== null && _mapOptions$user !== void 0 && _mapOptions$user.iconImage) {
    console.log('Adding User Options');
    const resolvedImage = _reactNative.Image.resolveAssetSource(mapOptions.user.iconImage);
    mapOptions.user.iconHeight = resolvedImage.height;
    mapOptions.user.iconWidth = resolvedImage.width;
    mapOptions.user.iconUrl = resolvedImage.uri;
    console.log(mapOptions.user.iconUrl);
  }
  console.log('Map Options: ' + mapOptions);
  _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.setMapVenue.toString(), [credentials, mapOptions]);
};
exports.setMapVenue = setMapVenue;
const setMapOptions = _ref2 => {
  var _options$user;
  let {
    viewId,
    options
  } = _ref2;
  console.log('Setting Map Options');
  if (options.user && (_options$user = options.user) !== null && _options$user !== void 0 && _options$user.iconImage) {
    console.log('Adding User Options');
    const resolvedImage = _reactNative.Image.resolveAssetSource(options.user.iconImage);
    options.user.iconHeight = resolvedImage.height;
    options.user.iconWidth = resolvedImage.width;
    options.user.iconUrl = resolvedImage.uri;
    console.log(options.user.iconUrl);
  }
  _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.setMapOptions.toString(), [options]);
};
exports.setMapOptions = setMapOptions;
const centerMapOnPoint = (viewId, point) => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.centerMapOnPoint.toString(), [point]);
exports.centerMapOnPoint = centerMapOnPoint;
const setFollowBlueDot = function (viewId, enabled) {
  let rotate = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  let interval = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 500;
  return _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.setFollowBlueDot.toString(), [enabled, rotate, interval]);
};
exports.setFollowBlueDot = setFollowBlueDot;
const setUserPosition = (viewId, x, y, heading, confidence, format) => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.setUserPosition.toString(), [x, y, heading, confidence, format]);
exports.setUserPosition = setUserPosition;
const clearWayfindingPath = viewId => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.clearWayfindingPath.toString(), []);
exports.clearWayfindingPath = clearWayfindingPath;
const wayfindToWaypoint = (viewId, waypointId) => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.wayfindToWaypoint.toString(), [waypointId]);
exports.wayfindToWaypoint = wayfindToWaypoint;
const wayfindBetweenWaypoints = (viewId, originId, destinationId) => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.wayfindBetweenWaypoints.toString(), [originId, destinationId]);
exports.wayfindBetweenWaypoints = wayfindBetweenWaypoints;
const drawNavigationPath = (viewId, pathId, shouldFocus, style) => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.drawNavigationPath.toString(), [pathId, shouldFocus, style]);
exports.drawNavigationPath = drawNavigationPath;
const styleUnitsForDestination = (viewId, destination, style) => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.styleUnitsForDestination.toString(), [destination, style]);
exports.styleUnitsForDestination = styleUnitsForDestination;
const styleShape = (viewId, id, style) => _reactNative.UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.styleShape.toString(), [id, style]);

// export const styleGeofences = (
//   viewId: number | null,
//   visible: boolean,
//   style: JIBESTREAM_STYLE
// ) =>
//   UIManager.dispatchViewManagerCommand(
//     viewId,
//     MapViewManagerCommands.styleGeofences.toString(),
//     [visible, style]
//   );
exports.styleShape = styleShape;
//# sourceMappingURL=SendCommand.js.map