import { UIManager, Platform, Image } from 'react-native';
import {
  JIBESTREAM_STYLE,
  MAP_CREDENTIALS,
  MAP_OPTIONS,
} from './JibestreamTypes';

interface MapViewManagerCommandMappings {
  create: number | string;
  center: number | string;
  setMapVenue: number | string;
  centerMapOnPoint: number | string;
  setFollowBlueDot: number | string;
  setUserPosition: number | string;
  setUserPositionXY: number | string;
  clearWayfindingPath: number | string;
  wayfindToWaypoint: number | string;
  wayfindBetweenWaypoints: number | string;
  drawNavigationPath: number | string;
  styleUnitsForDestination: number | string;
  styleShape: number | string;
  setMapOptions: number | string;
  //   styleGeofences: number | string;
}

let MapViewManagerCommands: MapViewManagerCommandMappings = {
  create: 1,
  center: 2,
  setMapVenue: 3,
  centerMapOnPoint: 4,
  setFollowBlueDot: 5,
  setUserPosition: 6,
  setUserPositionXY: 7,
  clearWayfindingPath: 8,
  wayfindToWaypoint: 9,
  wayfindBetweenWaypoints: 10,
  drawNavigationPath: 11,
  styleUnitsForDestination: 12,
  styleShape: 13,
  setMapOptions: 14,
  //   styleGeofences: 15,
};
if (Platform.OS == 'ios') {
  MapViewManagerCommands = {
    create: 'create',
    center: 'center',
    setMapVenue: 'setMapVenue',
    centerMapOnPoint: 'centerMapOnPoint',
    setFollowBlueDot: 'setFollowBlueDot',
    setUserPosition: 'setUserPosition',
    setUserPositionXY: 'setUserPositionXY',
    clearWayfindingPath: 'clearWayfindingPath',
    wayfindToWaypoint: 'wayfindToWaypoint',
    wayfindBetweenWaypoints: 'wayfindBetweenWaypoints',
    drawNavigationPath: 'drawNavigationPath',
    styleUnitsForDestination: 'styleUnitsForDestination',
    styleShape: 'styleShape',
    setMapOptions: 'setMapOptions',
    // styleGeofences: 'styleGeofences',
  };
}

export const createFragment = (viewId: number | null) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.create.toString(),
    [viewId]
  );

export const centerMap = (
  viewId: number | null,
  rotation: number,
  zoom: number,
  animationDuration: number
) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.center.toString(),
    [rotation, zoom, animationDuration]
  );

export function getRandomInt(max: number) {
  return Math.floor(Math.random() * max);
}

export const setMapVenue = ({
  viewId,
  credentials,
  mapOptions = {},
}: {
  viewId: number | null;
  credentials: MAP_CREDENTIALS;
  mapOptions?: MAP_OPTIONS;
}) => {
  console.log('Setting Map Options');
  if (mapOptions && mapOptions.user && mapOptions.user?.iconImage) {
    console.log('Adding User Options');
    const resolvedImage = Image.resolveAssetSource(mapOptions.user.iconImage);
    mapOptions.user.iconHeight = resolvedImage.height;
    mapOptions.user.iconWidth = resolvedImage.width;
    mapOptions.user.iconUrl = resolvedImage.uri;
    console.log(mapOptions.user.iconUrl);
  }

  console.log('Map Options: ' + mapOptions);

  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.setMapVenue.toString(),
    [credentials, mapOptions]
  );
};

export const setMapOptions = ({
  viewId,
  options,
}: {
  viewId: number | null;
  options: MAP_OPTIONS;
}) => {
  console.log('Setting Map Options');
  if (options.user && options.user?.iconImage) {
    console.log('Adding User Options');
    const resolvedImage = Image.resolveAssetSource(options.user.iconImage);
    options.user.iconHeight = resolvedImage.height;
    options.user.iconWidth = resolvedImage.width;
    options.user.iconUrl = resolvedImage.uri;
    console.log(options.user.iconUrl);
  }

  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.setMapOptions.toString(),
    [options]
  );
};

export const centerMapOnPoint = (viewId: number | null, point: number[]) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.centerMapOnPoint.toString(),
    [point]
  );

export const setFollowBlueDot = (
  viewId: number | null,
  enabled: boolean,
  rotate: boolean = false,
  interval: number = 500
) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.setFollowBlueDot.toString(),
    [enabled, rotate, interval]
  );

export const setUserPosition = (
  viewId: number | null,
  x: number,
  y: number,
  heading: number,
  confidence: number,
  format: string | null
) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.setUserPosition.toString(),
    [x, y, heading, confidence, format]
  );

export const clearWayfindingPath = (viewId: number | null) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.clearWayfindingPath.toString(),
    []
  );

export const wayfindToWaypoint = (viewId: number | null, waypointId: number) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.wayfindToWaypoint.toString(),
    [waypointId]
  );

export const wayfindBetweenWaypoints = (
  viewId: number | null,
  originId: number,
  destinationId: number
) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.wayfindBetweenWaypoints.toString(),
    [originId, destinationId]
  );

export const drawNavigationPath = (
  viewId: number | null,
  pathId: string,
  shouldFocus?: boolean,
  style?: JIBESTREAM_STYLE
) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.drawNavigationPath.toString(),
    [pathId, shouldFocus, style]
  );

export const styleUnitsForDestination = (
  viewId: number | null,
  destination: number,
  style?: JIBESTREAM_STYLE
) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.styleUnitsForDestination.toString(),
    [destination, style]
  );

export const styleShape = (
  viewId: number | null,
  id: number,
  style: JIBESTREAM_STYLE
) =>
  UIManager.dispatchViewManagerCommand(
    viewId,
    MapViewManagerCommands.styleShape.toString(),
    [id, style]
  );

// export const styleGeofences = (
//   viewId: number | null,
//   visible: boolean,
//   style: JIBESTREAM_STYLE
// ) =>
//   UIManager.dispatchViewManagerCommand(
//     viewId,
//     MapViewManagerCommands.styleGeofences.toString(),
//     [visible, style]
//   );
